@@ -1144,6 +1144,14 @@ def test_numcodecs(pyi_builder):
     """)
 
 
+@importorskip('pypemicro')
+def test_pypemicro(pyi_builder):
+    pyi_builder.test_source("""
+        from pypemicro import PyPemicro
+        assert PyPemicro.get_pemicro_lib()
+    """)
+
+
 @importorskip('sounddevice')
 def test_sounddevice(pyi_builder):
     pyi_builder.test_source("""
@@ -1156,3 +1164,26 @@ def test_soundfile(pyi_builder):
     pyi_builder.test_source("""
         import soundfile
     """)
+
+
+@importorskip('yt_dlp')
+def test_yt_dlp(pyi_builder):
+    pyi_builder.test_source("""
+        import yt_dlp
+    """)
+
+
+@importorskip('limits')
+def test_limits(pyi_builder):
+    pyi_builder.test_source("""
+        import limits
+    """)
+
+
+@pytest.mark.skipif(is_win,
+                    reason='On Windows, Weasyprint dependencies cannot be installed using Chocolatey.')
+@importorskip("weasyprint")
+def test_weasyprint(pyi_builder):
+    pyi_builder.test_source("""
+        import weasyprint
+        """)
